@@ -355,7 +355,7 @@ class DiskFreeHelper(ReadonlyVariable):
     def get_free_for(self, dn):
         try:
             dfdn = dn
-            while True:
+            while True and dfdn and dfdn.startswith("/"):
                 dfProcess = process("/bin/df", "--output=avail", dfdn)
                 data = dfProcess.readlines()
                 if len(data) > 1:
@@ -962,10 +962,12 @@ class VariableClBuilderIsoBasePath(Variable):
 
     def get(self):
         root_type_ext = self.Get('os_root_type_ext')
-        if root_type_ext in RootType.RebuildAvailable:
-            return path.join(self.Get('cl_builder_flash_path'), "tmp")
-        if root_type_ext in RootType.IsoScanGrub:
-            return path.join(self.Get('cl_isoscan_base_path'), "tmp")
+        flash_path = self.Get('cl_builder_flash_path')
+        isoscan_path = self.Get('cl_isoscan_base_path')
+        if root_type_ext in RootType.RebuildAvailable and flash_path:
+            return path.join(flash_path, "tmp")
+        if root_type_ext in RootType.IsoScanGrub and isoscan_path:
+            return path.join(isoscan_path, "tmp")
         return self.default_value
 
 
